<?php
/**
 * A debug output class for the web browser
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2013 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DebugWebOutput extends BaseFrameworkSystem implements Debugger, OutputStreamer {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$debugInstance	The prepared debug instance
	 */
	public static final function createDebugWebOutput () {
		// Get a new instance
		$debugInstance = new DebugWebOutput();

		// Return it
		return $debugInstance;
	}

	/**
	 * Outputs the given data directly, ignores $stripTags
	 *
	 * @param	$output		The HTML output
	 * @param	$stripTags	Whether HTML tags shall be stripped out
	 * @return	void
	 */
	public final function outputStream ($output, $stripTags = FALSE) {
		// Strip out <br />
		$output = str_replace('<br />', '', $output);
		print(stripslashes($output)."<br />\n");
	}

	/**
	 * Output the code
	 *
	 * @param	$outStream	Stream to output
	 * @param	$stripTags	Whether HTML tags shall be stripped out
	 * @return	void
	 */
	public final function output ($outStream = FALSE, $stripTags = FALSE) {
		// Empty output will be silently ignored
		if ($outStream !== FALSE) {
			$this->outputStream($outStream, $stripTags);
		} // END - if
	}

	/**
	 * Streams the data and maybe does something to it
	 *
	 * @param	$data	The data (string mostly) to "stream"
	 * @return	$data	The data (string mostly) to "stream"
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	public function streamData ($data) {
		self::createDebugInstance(__CLASS__)->debugOutput('Unhandled ' . strlen($data) . ' bytes in this stream.');
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}
}

// [EOF]
?>
